PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/density.h Source File

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

density.h
Go to the documentation of this file.
1
6 #ifndef DENSITY_H
7 #define DENSITY_H
8
13 double complex* realspace_state(int BAND_NUM, int KPOINT_NUM, pswf_t* wf, ppot_t* pps, int* fftg,
14 int* labels, double* coords);
15
20 double* ae_chg_density(pswf_t* wf, ppot_t* pps, int* fftg, int* labels, double* coords);
21
26 double* project_realspace_state(int BAND_NUM, int numtoproj, pswf_t* wf, pswf_t* wf_R, ppot_t* pps, int* fftg,
27 int* labels, double* coords, int* labels_R, double* coords_R);
28
33 double* realspace_state_ri(int BAND_NUM, int KPOINT_NUM, pswf_t* wf, ppot_t* pps, int* fftg,
34 int* labels, double* coords);
35
42 void write_volumetric(char* filename, double* x, int* fftg, double scale);
43
49 double* write_realspace_state_ri_return(char* filename1, char* filename2, int BAND_NUM, int KPOINT_NUM,
50 pswf_t* wf, ppot_t* pps, int* fftg,
51 int* labels, double* coords);
52
57 double* write_density_return(char* filename, pswf_t* wf, ppot_t* pps,
58 int* fftg, int* labels, double* coords);
59
63 void write_realspace_state_ri_noreturn(char* filename1, char* filename2, int BAND_NUM, int KPOINT_NUM,
64 pswf_t* wf, ppot_t* pps, int* fftg,
65 int* labels, double* coords);
66
70 void write_density_noreturn(char* filename, pswf_t* wf, ppot_t* pps,
71 int* fftg, int* labels, double* coords);
72
73 #endif
project_realspace_state
double * project_realspace_state(int BAND_NUM, int numtoproj, pswf_t *wf, pswf_t *wf_R, ppot_t *pps, int *fftg, int *labels, double *coords, int *labels_R, double *coords_R)
ppot
Definition: utils.h:48
write_realspace_state_ri_noreturn
void write_realspace_state_ri_noreturn(char *filename1, char *filename2, int BAND_NUM, int KPOINT_NUM, pswf_t *wf, ppot_t *pps, int *fftg, int *labels, double *coords)
write_density_noreturn
void write_density_noreturn(char *filename, pswf_t *wf, ppot_t *pps, int *fftg, int *labels, double *coords)
write_volumetric
void write_volumetric(char *filename, double *x, int *fftg, double scale)
pawpyseed.core.quadrature.x
list x
Definition: quadrature.py:9
write_density_return
double * write_density_return(char *filename, pswf_t *wf, ppot_t *pps, int *fftg, int *labels, double *coords)
pswf
Definition: utils.h:110
write_realspace_state_ri_return
double * write_realspace_state_ri_return(char *filename1, char *filename2, int BAND_NUM, int KPOINT_NUM, pswf_t *wf, ppot_t *pps, int *fftg, int *labels, double *coords)
realspace_state
double complex * realspace_state(int BAND_NUM, int KPOINT_NUM, pswf_t *wf, ppot_t *pps, int *fftg, int *labels, double *coords)
ae_chg_density
double * ae_chg_density(pswf_t *wf, ppot_t *pps, int *fftg, int *labels, double *coords)
realspace_state_ri
double * realspace_state_ri(int BAND_NUM, int KPOINT_NUM, pswf_t *wf, ppot_t *pps, int *fftg, int *labels, double *coords)